@@ -24,7 +24,7 @@ from .utils import (
     useCookieToDict,
     useHeadersToDict
 )
-from ._datetime import UseDateTime
+from ._datetime import useDateTime
 
 __all__ = [
     # data
@@ -51,5 +51,5 @@ __all__ = [
     'useCookieToDict',
     'useHeadersToDict',
 
-    'UseDateTime'
+    'useDateTime'
 ]
